/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

/**
 * This file tests the IntlMessageContext.jsm module.
 */


// Globals

var Cc = Components.classes;
var Ci = Components.interfaces;
var Cu = Components.utils;
var Cr = Components.results;

Cu.import("resource://gre/modules/IntlMessageContext.jsm");

add_test(function test_object_exists() {

  do_check_true(this.hasOwnProperty('MessageContext'));
  run_next_test();
});


add_test(function test_simpleCase() {
  const mc = new MessageContext('en-US');

  mc.addMessages('key = Value');

  const entity = mc.messages.get('key');

  equal(entity, 'Value');
  equal(mc.format(entity), 'Value');

  run_next_test();
});

add_test(function test_withArgument() {
  const mc = new MessageContext('en-US');

  mc.addMessages('key = Hello, { $name }');

  const entity = mc.messages.get('key');

  equal(mc.format(entity, {name: "Mary"}), 'Hello, Mary');

  run_next_test();
});

add_test(function test_withError() {
  const mc = new MessageContext('en-US');

  const errors = [];

  mc.addMessages('key = Hello, { $name2 }');

  const entity = mc.messages.get('key');

  equal(mc.format(entity, {name: "Mary"}, errors), 'Hello, name2');

  equal(errors.length, 1);

  run_next_test();
});


function run_test() {
  run_next_test();
}
